



pip check || 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
ipython -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
ipython3 -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
iptest -h || 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
iptest3 -h || 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
